@@ -1,8 +1,10 @@
-# Testing collections and workspaces
+"""Testing collections and workspaces."""
+# coding=utf-8
 
-from collections import OrderedDict
 import datetime
+import json
 import logging
+import os
 import random
 import re
 import sys
@@ -11,8 +13,8 @@ import pytest
 
 import fiona
 from fiona.collection import Collection
-from fiona.drvsupport import supported_drivers, driver_mode_mingdal
-from fiona.env import getenv, GDALVersion
+from fiona.drvsupport import supported_drivers
+from fiona.env import getenv
 from fiona.errors import (
     AttributeFilterError,
     FionaValueError,
@@ -21,7 +23,7 @@ from fiona.errors import (
 )
 from fiona.model import Feature, Geometry
 
-from .conftest import WGS84PATTERN, get_temp_filename
+from .conftest import WGS84PATTERN
 
 
 class TestSupportedDrivers:
@@ -99,15 +101,15 @@ class TestReading:
 
     def test_open_repr(self, path_coutwildrnp_shp):
         assert repr(self.c) == (
-            "<open Collection '{path}:coutwildrnp', mode 'r' "
-            "at {hexid}>".format(hexid=hex(id(self.c)), path=path_coutwildrnp_shp)
+            f"<open Collection '{path_coutwildrnp_shp}:coutwildrnp', "
+            f"mode 'r' at {hex(id(self.c))}>"
         )
 
     def test_closed_repr(self, path_coutwildrnp_shp):
         self.c.close()
         assert repr(self.c) == (
-            "<closed Collection '{path}:coutwildrnp', mode 'r' "
-            "at {hexid}>".format(hexid=hex(id(self.c)), path=path_coutwildrnp_shp)
+            f"<closed Collection '{path_coutwildrnp_shp}:coutwildrnp', "
+            f"mode 'r' at {hex(id(self.c))}>"
         )
 
     def test_path(self, path_coutwildrnp_shp):
@@ -341,7 +343,7 @@ class TestIgnoreFieldsAndGeometry:
                 "r",
                 include_fields=["AREA"],
                 ignore_fields=["STATE"],
-            ) as collection:
+            ):
                 pass
 
     def test_ignore_geometry(self):
@@ -401,14 +403,6 @@ class TestFilterReading:
         results = list(self.c.filter())
         assert len(results) == 67
 
-    def test_filter_bbox_where(self):
-        # combined filter criteria
-        results = set(self.c.keys(
-            bbox=(-120.0, 40.0, -100.0, 50.0), where="NAME LIKE 'Mount%'"))
-        assert results == set([0, 2, 5, 13])
-        results = set(self.c.keys())
-        assert len(results) == 67
-
     def test_filter_where_error(self):
         for w in ["bad stuff", "NAME=3", "NNAME LIKE 'Mount%'"]:
             with pytest.raises(AttributeFilterError):
@@ -423,11 +417,6 @@ class TestFilterReading:
         results = set(self.c.keys())
         assert len(results) == 67
 
-    def test_filter_where_error(self):
-        for w in ["bad stuff", "NAME=3", "NNAME LIKE 'Mount%'"]:
-            with pytest.raises(AttributeFilterError):
-                self.c.filter(where=w)
-
 
 class TestUnsupportedDriver:
     def test_immediate_fail_driver(self, tmpdir):
@@ -1035,12 +1024,12 @@ def test_open_kwargs(tmpdir, path_coutwildrnp_shp):
 @pytest.mark.network
 def test_collection_http():
     ds = fiona.Collection(
-        "https://raw.githubusercontent.com/Toblerity/Fiona/master/tests/data/coutwildrnp.shp",
+        "https://raw.githubusercontent.com/Toblerity/Fiona/main/tests/data/coutwildrnp.shp",
         vsi="https",
     )
     assert (
         ds.path
-        == "/vsicurl/https://raw.githubusercontent.com/Toblerity/Fiona/master/tests/data/coutwildrnp.shp"
+        == "/vsicurl/https://raw.githubusercontent.com/Toblerity/Fiona/main/tests/data/coutwildrnp.shp"
     )
     assert len(ds) == 67
 
@@ -1048,10 +1037,10 @@ def test_collection_http():
 @pytest.mark.network
 def test_collection_zip_http():
     ds = fiona.Collection(
-        "https://raw.githubusercontent.com/Toblerity/Fiona/master/tests/data/coutwildrnp.zip",
+        "https://raw.githubusercontent.com/Toblerity/Fiona/main/tests/data/coutwildrnp.zip",
         vsi="zip+https",
     )
-    assert ds.path == "/vsizip/vsicurl/https://raw.githubusercontent.com/Toblerity/Fiona/master/tests/data/coutwildrnp.zip"
+    assert ds.path == "/vsizip/vsicurl/https://raw.githubusercontent.com/Toblerity/Fiona/main/tests/data/coutwildrnp.zip"
     assert len(ds) == 67
 
 
@@ -1101,7 +1090,7 @@ def test_mask_polygon_triangle(tmpdir, driver, filename):
     """Test if mask works for non trivial geometries"""
     schema = {
         "geometry": "Polygon",
-        "properties": OrderedDict([("position_i", "int"), ("position_j", "int")]),
+        "properties": {"position_i": "int", "position_j": "int"},
     }
     records = [
         Feature.from_dict(
@@ -1202,3 +1191,28 @@ def test_driver_detection(tmpdir, extension, driver):
         crs="EPSG:4326",
     ) as output:
         assert output.driver == driver
+
+
+@pytest.mark.skipif(
+    sys.platform == "win32",
+    reason="Windows test runners don't have full unicode support",
+)
+def test_collection_name(tmp_path):
+    """A Collection name is plumbed all the way through."""
+    filename = os.fspath(tmp_path.joinpath("test.geojson"))
+
+    with fiona.Collection(
+        filename,
+        "w",
+        driver="GeoJSON",
+        crs="EPSG:4326",
+        schema={"geometry": "Point", "properties": {"foo": "int"}},
+        layer="Darwin Núñez",
+        write_name=True,
+    ) as colxn:
+        assert colxn.name == "Darwin Núñez"
+
+    with open(filename) as f:
+        geojson = json.load(f)
+
+    assert geojson["name"] == "Darwin Núñez"
