@@ -147,3 +147,41 @@ def test_to_wkt__invalid_version():
 def test_from_func_deprecations(func, arg):
     with pytest.warns(FionaDeprecationWarning):
         _ = func(arg)
+
+
+def test_xx():
+    """Create a CRS from WKT with a vertical datum."""
+    wkt = """
+COMPD_CS["NAD83(CSRS) / UTM zone 10N + CGVD28 height",
+PROJCS["NAD83(CSRS) / UTM zone 10N",
+GEOGCS["NAD83(CSRS)",
+DATUM["NAD83_Canadian_Spatial_Reference_System",
+SPHEROID["GRS 1980",6378137,298.257222101,
+AUTHORITY["EPSG","7019"]],
+AUTHORITY["EPSG","6140"]],
+PRIMEM["Greenwich",0,
+AUTHORITY["EPSG","8901"]],
+UNIT["degree",0.0174532925199433,
+AUTHORITY["EPSG","9122"]],
+AUTHORITY["EPSG","4617"]],
+PROJECTION["Transverse_Mercator"],
+PARAMETER["latitude_of_origin",0],
+PARAMETER["central_meridian",-123],
+PARAMETER["scale_factor",0.9996],
+PARAMETER["false_easting",500000],
+PARAMETER["false_northing",0],
+UNIT["metre",1,
+AUTHORITY["EPSG","9001"]],
+AXIS["Easting",EAST],
+AXIS["Northing",NORTH],
+AUTHORITY["EPSG","3157"]],
+VERT_CS["CGVD28 height",
+VERT_DATUM["Canadian Geodetic Vertical Datum of 1928",2005,
+AUTHORITY["EPSG","5114"]],
+UNIT["metre",1,
+AUTHORITY["EPSG","9001"]],
+AXIS["Gravity-related height",UP],
+AUTHORITY["EPSG","5713"]]]
+"""
+    val = crs.CRS.from_wkt(wkt)
+    assert val.wkt.startswith("COMPD_CS")
