@@ -2,7 +2,6 @@
 See also test_rfc3339.py for datetime parser tests.
 """
 
-from collections import OrderedDict
 import fiona
 from fiona._env import get_gdal_version_num, calc_gdal_version_num
 import pytest
@@ -31,19 +30,17 @@ gdal_version = GDALVersion.runtime()
 def get_schema(driver, field_type):
     if driver == "GPX":
         return {
-            "properties": OrderedDict([("ele", "float"), ("time", field_type)]),
+            "properties": {"ele": "float", "time": field_type},
             "geometry": "Point",
         }
     if driver == "GPSTrackMaker":
         return {
-            "properties": OrderedDict(
-                [
-                    ("name", "str"),
-                    ("comment", "str"),
-                    ("icon", "int"),
-                    ("time", field_type),
-                ]
-            ),
+            "properties": {
+                "name": "str",
+                "comment": "str",
+                "icon": "int",
+                "time": field_type,
+            },
             "geometry": "Point",
         }
     if driver == "CSV":
@@ -67,9 +64,7 @@ def get_records(driver, values):
             Feature.from_dict(
                 **{
                     "geometry": {"type": "Point", "coordinates": [1, 2]},
-                    "properties": OrderedDict(
-                        [("name", ""), ("comment", ""), ("icon", 48), ("time", val)]
-                    ),
+                    "properties": {"name": "", "comment": "", "icon": 48, "time": val},
                 }
             )
             for val in values
@@ -544,11 +539,9 @@ def test_datefield_driver_converts_to_string(tmpdir, driver, field_type):
             else:
                 sign, hours, minutes = get_tz_offset(val_exp)
                 if minutes > 0:
-                    tz = "{sign}{hours:02d}{minutes:02d}".format(
-                        sign=sign, hours=int(hours), minutes=int(minutes)
-                    )
+                    tz = f"{sign}{hours:02d}{minutes:02d}"
                 else:
-                    tz = f"{sign}{int(hours):02d}"
+                    tz = f"{sign}{hours:02d}"
                 print("tz", tz)
                 # No Milliseconds
                 if not _driver_supports_milliseconds(driver):
@@ -632,11 +625,9 @@ def test_datefield_driver_converts_to_string(tmpdir, driver, field_type):
 
                 sign, hours, minutes = get_tz_offset(val_exp)
                 if minutes > 0:
-                    tz = "{sign}{hours:02d}{minutes:02d}".format(
-                        sign=sign, hours=int(hours), minutes=int(minutes)
-                    )
+                    tz = f"{sign}{hours:02d}{minutes:02d}"
                 else:
-                    tz = f"{sign}{int(hours):02d}"
+                    tz = f"{sign}{hours:02d}"
                 # No Milliseconds
                 if not _driver_supports_milliseconds(driver):
                     if (
@@ -749,7 +740,7 @@ def test_datetime_field_type_marked_not_supported_is_not_supported(
 ):
     """Test if a date/datetime/time field type marked as not not supported is really not supported
 
-    Warning: Success of this test does not necessary mean that a field is not supported. E.g. errors can occour due to
+    Warning: Success of this test does not necessary mean that a field is not supported. E.g. errors can occur due to
     special schema requirements of drivers. This test only covers the standard case.
 
     """
@@ -836,3 +827,30 @@ def test_read_timezone_geojson(path_test_tz_geojson):
     with fiona.open(path_test_tz_geojson) as c:
         items = list(c)
         assert items[0]["properties"]["test"] == "2015-04-22T00:00:00+07:00"
+
+
+def test_property_setter_lookup(tmp_path):
+    """Demonstrate fix for #1376."""
+
+    class MyDate(datetime.date):
+        pass
+
+    feat = Feature.from_dict(
+        {
+            "properties": {"when": MyDate(2024, 4, 15)},
+            "geometry": {"type": "Point", "coordinates": [0, 0]},
+        }
+    )
+    with fiona.open(
+        tmp_path / "test.gpkg",
+        "w",
+        driver="GPKG",
+        crs="EPSG:4326",
+        schema={"geometry": "Point", "properties": {"when": "date"}},
+    ) as colxn:
+        colxn.writerecords([feat])
+
+    with fiona.open(tmp_path / "test.gpkg") as colxn:
+        assert colxn.schema["properties"]["when"] == "date"
+        feat = next(colxn)
+        assert feat.properties["when"] == "2024-04-15"
