@@ -333,3 +333,21 @@ def test_geometry_collection_encoding():
     assert "coordinates" not in ObjectEncoder().default(
         Geometry(type="GeometryCollection", geometries=[])
     )
+
+
+def test_feature_repr():
+    feat = Feature(
+        id="1",
+        geometry=Geometry(type="LineString", coordinates=[(0, 0)] * 100),
+        properties=Properties(a=1, foo="bar"),
+    )
+    assert repr(feat) == "fiona.Feature(geometry=fiona.Geometry(coordinates=[(0, 0), ...], type='LineString'), id='1', properties=fiona.Properties(a=1, foo='bar'))"
+
+
+def test_issue1430():
+    """__getitem__() returns property, not disconnected dict."""
+    feat = Feature(properties=Properties())
+    with pytest.warns(FionaDeprecationWarning, match="immutable"):
+        feat["properties"]["foo"] = "bar"
+    assert feat["properties"]["foo"] == "bar"
+    assert feat.properties["foo"] == "bar"
